==> zio-aws-imagebuilder_2.13-5.17.172.2-sources.jar: zio/aws/imagebuilder/model/UpdateImagePipelineRequest.scala <==
package zio.aws.imagebuilder.model
import zio.aws.imagebuilder.model.primitives.{
  DistributionConfigurationArn,
  ImageRecipeArn,
  InfrastructureConfigurationArn,
  ImagePipelineArn,
  ClientToken,
  ContainerRecipeArn,
  NullableBoolean,
  NonEmptyString
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateImagePipelineRequest(
    imagePipelineArn: ImagePipelineArn,
    description: Optional[NonEmptyString] = Optional.Absent,
    imageRecipeArn: Optional[ImageRecipeArn] = Optional.Absent,
    containerRecipeArn: Optional[ContainerRecipeArn] = Optional.Absent,
    infrastructureConfigurationArn: InfrastructureConfigurationArn,
    distributionConfigurationArn: Optional[DistributionConfigurationArn] =
      Optional.Absent,
    imageTestsConfiguration: Optional[
      zio.aws.imagebuilder.model.ImageTestsConfiguration
    ] = Optional.Absent,
    enhancedImageMetadataEnabled: Optional[NullableBoolean] = Optional.Absent,
    schedule: Optional[zio.aws.imagebuilder.model.Schedule] = Optional.Absent,
    status: Optional[zio.aws.imagebuilder.model.PipelineStatus] =
      Optional.Absent,
    clientToken: ClientToken
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.imagebuilder.model.UpdateImagePipelineRequest = {
    import UpdateImagePipelineRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.imagebuilder.model.UpdateImagePipelineRequest
      .builder()
      .imagePipelineArn(
        ImagePipelineArn.unwrap(imagePipelineArn): java.lang.String
      )
      .optionallyWith(
        description.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        imageRecipeArn.map(value =>
          ImageRecipeArn.unwrap(value): java.lang.String
        )
      )(_.imageRecipeArn)
      .optionallyWith(
        containerRecipeArn.map(value =>
          ContainerRecipeArn.unwrap(value): java.lang.String
        )
      )(_.containerRecipeArn)
      .infrastructureConfigurationArn(
        InfrastructureConfigurationArn.unwrap(
          infrastructureConfigurationArn
        ): java.lang.String
      )
      .optionallyWith(
        distributionConfigurationArn.map(value =>
          DistributionConfigurationArn.unwrap(value): java.lang.String
        )
      )(_.distributionConfigurationArn)
      .optionallyWith(
        imageTestsConfiguration.map(value => value.buildAwsValue())
      )(_.imageTestsConfiguration)
      .optionallyWith(
        enhancedImageMetadataEnabled.map(value => value: java.lang.Boolean)
      )(_.enhancedImageMetadataEnabled)
      .optionallyWith(schedule.map(value => value.buildAwsValue()))(_.schedule)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .clientToken(ClientToken.unwrap(clientToken): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.imagebuilder.model.UpdateImagePipelineRequest.ReadOnly =
    zio.aws.imagebuilder.model.UpdateImagePipelineRequest.wrap(buildAwsValue())
}
object UpdateImagePipelineRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.imagebuilder.model.UpdateImagePipelineRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.imagebuilder.model.UpdateImagePipelineRequest =
      zio.aws.imagebuilder.model.UpdateImagePipelineRequest(
        imagePipelineArn,
        description.map(value => value),
        imageRecipeArn.map(value => value),
        containerRecipeArn.map(value => value),
        infrastructureConfigurationArn,
        distributionConfigurationArn.map(value => value),
        imageTestsConfiguration.map(value => value.asEditable),
        enhancedImageMetadataEnabled.map(value => value),
        schedule.map(value => value.asEditable),
        status.map(value => value),
        clientToken
      )
    def imagePipelineArn: ImagePipelineArn
    def description: Optional[NonEmptyString]
    def imageRecipeArn: Optional[ImageRecipeArn]
    def containerRecipeArn: Optional[ContainerRecipeArn]
    def infrastructureConfigurationArn: InfrastructureConfigurationArn
    def distributionConfigurationArn: Optional[DistributionConfigurationArn]
    def imageTestsConfiguration
        : Optional[zio.aws.imagebuilder.model.ImageTestsConfiguration.ReadOnly]
    def enhancedImageMetadataEnabled: Optional[NullableBoolean]
    def schedule: Optional[zio.aws.imagebuilder.model.Schedule.ReadOnly]
    def status: Optional[zio.aws.imagebuilder.model.PipelineStatus]
    def clientToken: ClientToken
    def getImagePipelineArn: ZIO[Any, Nothing, ImagePipelineArn] =
      ZIO.succeed(imagePipelineArn)
    def getDescription: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("description", description)
    def getImageRecipeArn: ZIO[Any, AwsError, ImageRecipeArn] =
      AwsError.unwrapOptionField("imageRecipeArn", imageRecipeArn)
    def getContainerRecipeArn: ZIO[Any, AwsError, ContainerRecipeArn] =
      AwsError.unwrapOptionField("containerRecipeArn", containerRecipeArn)
    def getInfrastructureConfigurationArn
        : ZIO[Any, Nothing, InfrastructureConfigurationArn] =
      ZIO.succeed(infrastructureConfigurationArn)
    def getDistributionConfigurationArn
        : ZIO[Any, AwsError, DistributionConfigurationArn] =
      AwsError.unwrapOptionField(
        "distributionConfigurationArn",
        distributionConfigurationArn
      )
    def getImageTestsConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.imagebuilder.model.ImageTestsConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "imageTestsConfiguration",
      imageTestsConfiguration
    )
    def getEnhancedImageMetadataEnabled: ZIO[Any, AwsError, NullableBoolean] =
      AwsError.unwrapOptionField(
        "enhancedImageMetadataEnabled",
        enhancedImageMetadataEnabled
      )
    def getSchedule
        : ZIO[Any, AwsError, zio.aws.imagebuilder.model.Schedule.ReadOnly] =
      AwsError.unwrapOptionField("schedule", schedule)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.imagebuilder.model.PipelineStatus] =
      AwsError.unwrapOptionField("status", status)
    def getClientToken: ZIO[Any, Nothing, ClientToken] =
      ZIO.succeed(clientToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.imagebuilder.model.UpdateImagePipelineRequest
  ) extends zio.aws.imagebuilder.model.UpdateImagePipelineRequest.ReadOnly {
    override val imagePipelineArn: ImagePipelineArn =
      zio.aws.imagebuilder.model.primitives
        .ImagePipelineArn(impl.imagePipelineArn())
    override val description: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.imagebuilder.model.primitives.NonEmptyString(value))
    override val imageRecipeArn: Optional[ImageRecipeArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.imageRecipeArn())
        .map(value =>
          zio.aws.imagebuilder.model.primitives.ImageRecipeArn(value)
        )
    override val containerRecipeArn: Optional[ContainerRecipeArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.containerRecipeArn())
        .map(value =>
          zio.aws.imagebuilder.model.primitives.ContainerRecipeArn(value)
        )
    override val infrastructureConfigurationArn
        : InfrastructureConfigurationArn = zio.aws.imagebuilder.model.primitives
      .InfrastructureConfigurationArn(impl.infrastructureConfigurationArn())
    override val distributionConfigurationArn
        : Optional[DistributionConfigurationArn] = zio.aws.core.internal
      .optionalFromNullable(impl.distributionConfigurationArn())
      .map(value =>
        zio.aws.imagebuilder.model.primitives
          .DistributionConfigurationArn(value)
      )
    override val imageTestsConfiguration: Optional[
      zio.aws.imagebuilder.model.ImageTestsConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.imageTestsConfiguration())
      .map(value =>
        zio.aws.imagebuilder.model.ImageTestsConfiguration.wrap(value)
      )
    override val enhancedImageMetadataEnabled: Optional[NullableBoolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.enhancedImageMetadataEnabled())
        .map(value => value: NullableBoolean)
    override val schedule
        : Optional[zio.aws.imagebuilder.model.Schedule.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.schedule())
        .map(value => zio.aws.imagebuilder.model.Schedule.wrap(value))
    override val status: Optional[zio.aws.imagebuilder.model.PipelineStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.imagebuilder.model.PipelineStatus.wrap(value))
    override val clientToken: ClientToken =
      zio.aws.imagebuilder.model.primitives.ClientToken(impl.clientToken())
  }
  def wrap(
      impl: software.amazon.awssdk.services.imagebuilder.model.UpdateImagePipelineRequest
  ): zio.aws.imagebuilder.model.UpdateImagePipelineRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-imagebuilder_2.13-6.20.42.2-sources.jar: zio/aws/imagebuilder/model/UpdateImagePipelineRequest.scala <==
package zio.aws.imagebuilder.model
import zio.aws.imagebuilder.model.primitives.{
  DistributionConfigurationArn,
  ImageRecipeArn,
  InfrastructureConfigurationArn,
  ImagePipelineArn,
  ClientToken,
  ContainerRecipeArn,
  NullableBoolean,
  NonEmptyString
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateImagePipelineRequest(
    imagePipelineArn: ImagePipelineArn,
    description: Optional[NonEmptyString] = Optional.Absent,
    imageRecipeArn: Optional[ImageRecipeArn] = Optional.Absent,
    containerRecipeArn: Optional[ContainerRecipeArn] = Optional.Absent,
    infrastructureConfigurationArn: InfrastructureConfigurationArn,
    distributionConfigurationArn: Optional[DistributionConfigurationArn] =
      Optional.Absent,
    imageTestsConfiguration: Optional[
      zio.aws.imagebuilder.model.ImageTestsConfiguration
    ] = Optional.Absent,
    enhancedImageMetadataEnabled: Optional[NullableBoolean] = Optional.Absent,
    schedule: Optional[zio.aws.imagebuilder.model.Schedule] = Optional.Absent,
    status: Optional[zio.aws.imagebuilder.model.PipelineStatus] =
      Optional.Absent,
    clientToken: ClientToken,
    imageScanningConfiguration: Optional[
      zio.aws.imagebuilder.model.ImageScanningConfiguration
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.imagebuilder.model.UpdateImagePipelineRequest = {
    import UpdateImagePipelineRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.imagebuilder.model.UpdateImagePipelineRequest
      .builder()
      .imagePipelineArn(
        ImagePipelineArn.unwrap(imagePipelineArn): java.lang.String
      )
      .optionallyWith(
        description.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        imageRecipeArn.map(value =>
          ImageRecipeArn.unwrap(value): java.lang.String
        )
      )(_.imageRecipeArn)
      .optionallyWith(
        containerRecipeArn.map(value =>
          ContainerRecipeArn.unwrap(value): java.lang.String
        )
      )(_.containerRecipeArn)
      .infrastructureConfigurationArn(
        InfrastructureConfigurationArn.unwrap(
          infrastructureConfigurationArn
        ): java.lang.String
      )
      .optionallyWith(
        distributionConfigurationArn.map(value =>
          DistributionConfigurationArn.unwrap(value): java.lang.String
        )
      )(_.distributionConfigurationArn)
      .optionallyWith(
        imageTestsConfiguration.map(value => value.buildAwsValue())
      )(_.imageTestsConfiguration)
      .optionallyWith(
        enhancedImageMetadataEnabled.map(value => value: java.lang.Boolean)
      )(_.enhancedImageMetadataEnabled)
      .optionallyWith(schedule.map(value => value.buildAwsValue()))(_.schedule)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .clientToken(ClientToken.unwrap(clientToken): java.lang.String)
      .optionallyWith(
        imageScanningConfiguration.map(value => value.buildAwsValue())
      )(_.imageScanningConfiguration)
      .build()
  }
  def asReadOnly
      : zio.aws.imagebuilder.model.UpdateImagePipelineRequest.ReadOnly =
    zio.aws.imagebuilder.model.UpdateImagePipelineRequest.wrap(buildAwsValue())
}
object UpdateImagePipelineRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.imagebuilder.model.UpdateImagePipelineRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.imagebuilder.model.UpdateImagePipelineRequest =
      zio.aws.imagebuilder.model.UpdateImagePipelineRequest(
        imagePipelineArn,
        description.map(value => value),
        imageRecipeArn.map(value => value),
        containerRecipeArn.map(value => value),
        infrastructureConfigurationArn,
        distributionConfigurationArn.map(value => value),
        imageTestsConfiguration.map(value => value.asEditable),
        enhancedImageMetadataEnabled.map(value => value),
        schedule.map(value => value.asEditable),
        status.map(value => value),
        clientToken,
        imageScanningConfiguration.map(value => value.asEditable)
      )
    def imagePipelineArn: ImagePipelineArn
    def description: Optional[NonEmptyString]
    def imageRecipeArn: Optional[ImageRecipeArn]
    def containerRecipeArn: Optional[ContainerRecipeArn]
    def infrastructureConfigurationArn: InfrastructureConfigurationArn
    def distributionConfigurationArn: Optional[DistributionConfigurationArn]
    def imageTestsConfiguration
        : Optional[zio.aws.imagebuilder.model.ImageTestsConfiguration.ReadOnly]
    def enhancedImageMetadataEnabled: Optional[NullableBoolean]
    def schedule: Optional[zio.aws.imagebuilder.model.Schedule.ReadOnly]
    def status: Optional[zio.aws.imagebuilder.model.PipelineStatus]
    def clientToken: ClientToken
    def imageScanningConfiguration: Optional[
      zio.aws.imagebuilder.model.ImageScanningConfiguration.ReadOnly
    ]
    def getImagePipelineArn: ZIO[Any, Nothing, ImagePipelineArn] =
      ZIO.succeed(imagePipelineArn)
    def getDescription: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("description", description)
    def getImageRecipeArn: ZIO[Any, AwsError, ImageRecipeArn] =
      AwsError.unwrapOptionField("imageRecipeArn", imageRecipeArn)
    def getContainerRecipeArn: ZIO[Any, AwsError, ContainerRecipeArn] =
      AwsError.unwrapOptionField("containerRecipeArn", containerRecipeArn)
    def getInfrastructureConfigurationArn
        : ZIO[Any, Nothing, InfrastructureConfigurationArn] =
      ZIO.succeed(infrastructureConfigurationArn)
    def getDistributionConfigurationArn
        : ZIO[Any, AwsError, DistributionConfigurationArn] =
      AwsError.unwrapOptionField(
        "distributionConfigurationArn",
        distributionConfigurationArn
      )
    def getImageTestsConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.imagebuilder.model.ImageTestsConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "imageTestsConfiguration",
      imageTestsConfiguration
    )
    def getEnhancedImageMetadataEnabled: ZIO[Any, AwsError, NullableBoolean] =
      AwsError.unwrapOptionField(
        "enhancedImageMetadataEnabled",
        enhancedImageMetadataEnabled
      )
    def getSchedule
        : ZIO[Any, AwsError, zio.aws.imagebuilder.model.Schedule.ReadOnly] =
      AwsError.unwrapOptionField("schedule", schedule)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.imagebuilder.model.PipelineStatus] =
      AwsError.unwrapOptionField("status", status)
    def getClientToken: ZIO[Any, Nothing, ClientToken] =
      ZIO.succeed(clientToken)
    def getImageScanningConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.imagebuilder.model.ImageScanningConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "imageScanningConfiguration",
      imageScanningConfiguration
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.imagebuilder.model.UpdateImagePipelineRequest
  ) extends zio.aws.imagebuilder.model.UpdateImagePipelineRequest.ReadOnly {
    override val imagePipelineArn: ImagePipelineArn =
      zio.aws.imagebuilder.model.primitives
        .ImagePipelineArn(impl.imagePipelineArn())
    override val description: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.imagebuilder.model.primitives.NonEmptyString(value))
    override val imageRecipeArn: Optional[ImageRecipeArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.imageRecipeArn())
        .map(value =>
          zio.aws.imagebuilder.model.primitives.ImageRecipeArn(value)
        )
    override val containerRecipeArn: Optional[ContainerRecipeArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.containerRecipeArn())
        .map(value =>
          zio.aws.imagebuilder.model.primitives.ContainerRecipeArn(value)
        )
    override val infrastructureConfigurationArn
        : InfrastructureConfigurationArn = zio.aws.imagebuilder.model.primitives
      .InfrastructureConfigurationArn(impl.infrastructureConfigurationArn())
    override val distributionConfigurationArn
        : Optional[DistributionConfigurationArn] = zio.aws.core.internal
      .optionalFromNullable(impl.distributionConfigurationArn())
      .map(value =>
        zio.aws.imagebuilder.model.primitives
          .DistributionConfigurationArn(value)
      )
    override val imageTestsConfiguration: Optional[
      zio.aws.imagebuilder.model.ImageTestsConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.imageTestsConfiguration())
      .map(value =>
        zio.aws.imagebuilder.model.ImageTestsConfiguration.wrap(value)
      )
    override val enhancedImageMetadataEnabled: Optional[NullableBoolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.enhancedImageMetadataEnabled())
        .map(value => value: NullableBoolean)
    override val schedule
        : Optional[zio.aws.imagebuilder.model.Schedule.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.schedule())
        .map(value => zio.aws.imagebuilder.model.Schedule.wrap(value))
    override val status: Optional[zio.aws.imagebuilder.model.PipelineStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.imagebuilder.model.PipelineStatus.wrap(value))
    override val clientToken: ClientToken =
      zio.aws.imagebuilder.model.primitives.ClientToken(impl.clientToken())
    override val imageScanningConfiguration: Optional[
      zio.aws.imagebuilder.model.ImageScanningConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.imageScanningConfiguration())
      .map(value =>
        zio.aws.imagebuilder.model.ImageScanningConfiguration.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.imagebuilder.model.UpdateImagePipelineRequest
  ): zio.aws.imagebuilder.model.UpdateImagePipelineRequest.ReadOnly =
    new Wrapper(impl)
}
